@@ -6,13 +6,13 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAINWINDOW_H
-#define MAINWINDOW_H
+#pragma once
 
 #include <KXmlGuiWindow>
 
 class MainWidget;
 class KToggleAction;
+class KHamburgerMenu;
 class MainWindow : public KXmlGuiWindow
 {
     Q_OBJECT
@@ -31,9 +31,10 @@ private:
     void slotToggleMenubar(bool dontShowWarning);
 
     void initActions();
+    void updateHamburgerMenu();
 
     MainWidget *mMainWidget = nullptr;
-    KToggleAction *mHideMenuBarAction = nullptr;
+    KToggleAction *mShowMenuBarAction = nullptr;
+    KHamburgerMenu *mHamburgerMenu = nullptr;
 };
 
-#endif
